@@ -30,6 +30,10 @@
 #include <fribidi-unicode.h>
 
 #include <stdio.h>
+#ifdef HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #ifdef STDC_HEADERS
 # include <stdlib.h>
 # include <stddef.h>
